==> jc-1.4.0.tar.gz: soot/jimple/toolkits/callgraph/CHATransformer.h <==
// public class soot.jimple.toolkits.callgraph.CHATransformer

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 1988ae632461b86a soot_SceneTransformer
// @dep_class de5fa3182955e270 soot_Transformer
// @dep_class 3a9ef3feb93fbe0c soot_jimple_toolkits_callgraph_CHATransformer

// header file dependencies
// @dep_header soot_SceneTransformer

#include "soot/SceneTransformer.h"

#ifndef _JC_soot_jimple_toolkits_callgraph_CHATransformer_H_
#define _JC_soot_jimple_toolkits_callgraph_CHATransformer_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Map$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_jimple_toolkits_callgraph_CHATransformer$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_callgraph_CHATransformer$sub_refs	_jc_soot_jimple_toolkits_callgraph_CHATransformer$sub_refs;
typedef struct _jc_soot_jimple_toolkits_callgraph_CHATransformer$sub_nonrefs	_jc_soot_jimple_toolkits_callgraph_CHATransformer$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_callgraph_CHATransformer$refs	_jc_soot_jimple_toolkits_callgraph_CHATransformer$refs;
typedef struct _jc_soot_jimple_toolkits_callgraph_CHATransformer$nonrefs	_jc_soot_jimple_toolkits_callgraph_CHATransformer$nonrefs;
typedef struct _jc_soot_jimple_toolkits_callgraph_CHATransformer$object	_jc_soot_jimple_toolkits_callgraph_CHATransformer$object;

typedef const struct _jc_soot_jimple_toolkits_callgraph_CHATransformer$vmethods	_jc_soot_jimple_toolkits_callgraph_CHATransformer$vmethods;
typedef const struct _jc_soot_jimple_toolkits_callgraph_CHATransformer$vtable	_jc_soot_jimple_toolkits_callgraph_CHATransformer$vtable;
typedef const struct _jc_soot_jimple_toolkits_callgraph_CHATransformer$vtype	_jc_soot_jimple_toolkits_callgraph_CHATransformer$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_callgraph_CHATransformer$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_CHATransformer$object *, struct _jc_soot_Singletons__24Global$object *);

// Virtual methods
extern void _jc_soot_jimple_toolkits_callgraph_CHATransformer$method$internalTransform$b44b61d0d9f22a06(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_CHATransformer$object *, struct _jc_java_lang_String$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_callgraph_CHATransformer$method_info$internalTransform$b44b61d0d9f22a06;

// Static methods
extern struct _jc_soot_jimple_toolkits_callgraph_CHATransformer$object *_jc_soot_jimple_toolkits_callgraph_CHATransformer$method$v$529e32d917f35f47(_jc_env *);

// Virtual methods structure
struct _jc_soot_jimple_toolkits_callgraph_CHATransformer$vmethods {
	void	(*internalTransform$b44b61d0d9f22a06)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_CHATransformer$object *, struct _jc_java_lang_String$object *, struct _jc_object *);
};

// Vtable
struct _jc_soot_jimple_toolkits_callgraph_CHATransformer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_Transformer$vmethods	soot_Transformer;
	_jc_soot_SceneTransformer$vmethods	soot_SceneTransformer;
	_jc_soot_jimple_toolkits_callgraph_CHATransformer$vmethods	soot_jimple_toolkits_callgraph_CHATransformer;
};

// Vtype
struct _jc_soot_jimple_toolkits_callgraph_CHATransformer$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_callgraph_CHATransformer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_callgraph_CHATransformer$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_callgraph_CHATransformer$refs {
    _jc_soot_jimple_toolkits_callgraph_CHATransformer$sub_refs	soot_jimple_toolkits_callgraph_CHATransformer;
    _jc_soot_SceneTransformer$sub_refs	soot_SceneTransformer;
    _jc_soot_Transformer$sub_refs	soot_Transformer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_callgraph_CHATransformer$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_callgraph_CHATransformer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_Transformer$sub_nonrefs	soot_Transformer;
    _jc_soot_SceneTransformer$sub_nonrefs	soot_SceneTransformer;
    _jc_soot_jimple_toolkits_callgraph_CHATransformer$sub_nonrefs	soot_jimple_toolkits_callgraph_CHATransformer;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_callgraph_CHATransformer$object {
	_jc_soot_jimple_toolkits_callgraph_CHATransformer$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_callgraph_CHATransformer$vtype	*vtype;
	_jc_soot_jimple_toolkits_callgraph_CHATransformer$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_callgraph_CHATransformer$vtype _jc_soot_jimple_toolkits_callgraph_CHATransformer$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_callgraph_CHATransformer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_callgraph_CHATransformer$class_object;

#endif	/* _JC_soot_jimple_toolkits_callgraph_CHATransformer_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/toolkits/callgraph/CHATransformer.h <==
// public class soot.jimple.toolkits.callgraph.CHATransformer

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 1988ae632461b86a soot_SceneTransformer
// @dep_class de5fa3182955e270 soot_Transformer
// @dep_class 3a9ef3feb93fbe0c soot_jimple_toolkits_callgraph_CHATransformer

// header file dependencies
// @dep_header soot_SceneTransformer

#include "soot/SceneTransformer.h"

#ifndef _JC_soot_jimple_toolkits_callgraph_CHATransformer_H_
#define _JC_soot_jimple_toolkits_callgraph_CHATransformer_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Map$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_jimple_toolkits_callgraph_CHATransformer$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_callgraph_CHATransformer$sub_refs	_jc_soot_jimple_toolkits_callgraph_CHATransformer$sub_refs;
typedef struct _jc_soot_jimple_toolkits_callgraph_CHATransformer$sub_nonrefs	_jc_soot_jimple_toolkits_callgraph_CHATransformer$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_callgraph_CHATransformer$refs	_jc_soot_jimple_toolkits_callgraph_CHATransformer$refs;
typedef struct _jc_soot_jimple_toolkits_callgraph_CHATransformer$nonrefs	_jc_soot_jimple_toolkits_callgraph_CHATransformer$nonrefs;
typedef struct _jc_soot_jimple_toolkits_callgraph_CHATransformer$object	_jc_soot_jimple_toolkits_callgraph_CHATransformer$object;

typedef const struct _jc_soot_jimple_toolkits_callgraph_CHATransformer$vmethods	_jc_soot_jimple_toolkits_callgraph_CHATransformer$vmethods;
typedef const struct _jc_soot_jimple_toolkits_callgraph_CHATransformer$vtable	_jc_soot_jimple_toolkits_callgraph_CHATransformer$vtable;
typedef const struct _jc_soot_jimple_toolkits_callgraph_CHATransformer$vtype	_jc_soot_jimple_toolkits_callgraph_CHATransformer$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_callgraph_CHATransformer$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_CHATransformer$object *, struct _jc_soot_Singletons__24Global$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_toolkits_callgraph_CHATransformer$method$internalTransform$b44b61d0d9f22a06(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_CHATransformer$object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_callgraph_CHATransformer$method_info$internalTransform$b44b61d0d9f22a06;

// Static methods
extern struct _jc_soot_jimple_toolkits_callgraph_CHATransformer$object *_jc_soot_jimple_toolkits_callgraph_CHATransformer$method$v$529e32d917f35f47(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_callgraph_CHATransformer$vmethods {
	void	(*internalTransform$b44b61d0d9f22a06)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_CHATransformer$object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_toolkits_callgraph_CHATransformer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_Transformer$vmethods	soot_Transformer;
	_jc_soot_SceneTransformer$vmethods	soot_SceneTransformer;
	_jc_soot_jimple_toolkits_callgraph_CHATransformer$vmethods	soot_jimple_toolkits_callgraph_CHATransformer;
};

// Vtype
struct _jc_soot_jimple_toolkits_callgraph_CHATransformer$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_callgraph_CHATransformer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_callgraph_CHATransformer$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_callgraph_CHATransformer$refs {
    _jc_soot_jimple_toolkits_callgraph_CHATransformer$sub_refs	soot_jimple_toolkits_callgraph_CHATransformer;
    _jc_soot_SceneTransformer$sub_refs	soot_SceneTransformer;
    _jc_soot_Transformer$sub_refs	soot_Transformer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_callgraph_CHATransformer$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_callgraph_CHATransformer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_Transformer$sub_nonrefs	soot_Transformer;
    _jc_soot_SceneTransformer$sub_nonrefs	soot_SceneTransformer;
    _jc_soot_jimple_toolkits_callgraph_CHATransformer$sub_nonrefs	soot_jimple_toolkits_callgraph_CHATransformer;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_callgraph_CHATransformer$object {
	_jc_soot_jimple_toolkits_callgraph_CHATransformer$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_callgraph_CHATransformer$vtype	*vtype;
	_jc_soot_jimple_toolkits_callgraph_CHATransformer$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_callgraph_CHATransformer$vtype _jc_soot_jimple_toolkits_callgraph_CHATransformer$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_callgraph_CHATransformer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_callgraph_CHATransformer$class_object;

#endif	/* _JC_soot_jimple_toolkits_callgraph_CHATransformer_H_ */
